@@ -104,9 +104,11 @@ class PlyLexer:
         "final",
         "float",
         "for",
+        "__forceinline",
         "friend",
         "goto",
         "if",
+        "__inline",
         "inline",
         "int",
         "long",
@@ -115,7 +117,6 @@ class PlyLexer:
         "new",
         "noexcept",
         "nullptr",
-        "nullptr_t",  # not a keyword, but makes things easier
         "operator",
         "private",
         "protected",
@@ -123,6 +124,8 @@ class PlyLexer:
         "register",
         "reinterpret_cast",
         "requires",
+        "__restrict__",
+        "restrict",
         "return",
         "short",
         "signed",
